summaryrefslogtreecommitdiffstats
path: root/tdecore/klockfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/klockfile.h')
-rw-r--r--tdecore/klockfile.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/tdecore/klockfile.h b/tdecore/klockfile.h
index f3bf0b0bc..be347ab56 100644
--- a/tdecore/klockfile.h
+++ b/tdecore/klockfile.h
@@ -25,22 +25,22 @@
#include <ksharedptr.h>
/**
* The KLockFile class provides NFS safe lockfiles.
*
* @author Waldo Bastian <bastian@kde.org>
* @since 3.3
*/
-class TDECORE_EXPORT KLockFile : public TDEShared
+class TDECORE_EXPORT TDELockFile : public TDEShared
{
public:
- typedef TDESharedPtr<KLockFile> Ptr;
+ typedef TDESharedPtr<TDELockFile> Ptr;
- KLockFile(const TQString &file);
+ TDELockFile(const TQString &file);
/**
* Destroys the object, releasing the lock if held
**/
- ~KLockFile();
+ ~TDELockFile();
/**
* Possible return values of the lock function.
@@ -116,8 +116,8 @@ public:
bool getLockInfo(int &pid, TQString &hostname, TQString &appname);
private:
- class KLockFilePrivate;
- KLockFilePrivate *d;
+ class TDELockFilePrivate;
+ TDELockFilePrivate *d;
};
#endif
@@ -25,22 +25,22 @@
#include <ksharedptr.h>
/**
- * The KLockFile class provides NFS safe lockfiles.
+ * The TDELockFile class provides NFS safe lockfiles.
*
* @author Waldo Bastian <bastian@kde.org>